==> HostCMS-6.1.7.tar: modules/lib/property/i18n/ru.php <==
<?php
/**
 * Libs.
 *
 * @package HostCMS 6\Lib
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2012 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Свойства типовой динамической страницы',
	'markDeleted_success' => 'Свойство типовой динамической страницы успешно удалено!',
	'lib_property_show_title' => 'Параметры типовой динамической страницы "%s"',
	'lib_property_parametr' => 'Параметр',
	'lib_property_add' => 'Добавить',
	'lib_property_form_title_add' => 'Добавление параметра типовой динамической страницы',
	'name' => '<acronym title="Название параметра типовой динамической страницы">Название параметра</acronym>',
	'description' => '<acronym title="Описание параметра типовой динамической страницы">Описание параметра</acronym>',
	'varible_name' => '<acronym title="Название переменной параметра типовой динамической страницы">Название переменной</acronym>',
	'type' => "<acronym title=\"Тип дополнительного свойства параметра типовой динамической страницы.\">Тип</acronym>",
	'default_value' => '<acronym title="Значение по умолчанию параметра динамической страницы">Значение по умолчанию</acronym>',
	'sorting' => '<acronym title="Порядок сортировки параметра динамической страницы">Порядок сортировки</acronym>',
	'lib_property_form_title_edit' => 'Редактирование параметра типовой динамической страницы',
	'id' => 'Идентификатор',
	'lib_id' => 'Идентификатор типовой динамической страницы',
	'lib_property_type_0' => 'Поле ввода',
	'lib_property_type_1' => 'Флажок',
	'lib_property_type_2' => 'XSL-шаблон',
	'lib_property_type_3' => 'Список',
	'lib_property_type_4' => 'SQL-запрос',
	'lib_property_type_5' => 'Большое текстовое поле',
	'copy_from' => ' [Копия от %s]' ,
	'sql_request' => '<acronym title="Текст SQL-запроса">SQL-запрос</acronym>',
	'sql_caption_field' => '<acronym title="Поле таблицы, служащее заголовком при отображении данных запроса">Поле заголовка</acronym>',
	'sql_value_field' => '<acronym title="Поле таблицы, из которого извлекается значение">Поле значения</acronym>',
	'edit_success' => 'Данные о параметрах динамической странице успешно добавлены/обновлены',
	'edit_error' => 'Ошибка добавления информации о параметре динамической страницы',
	'apply_success' => 'Информация изменена',
	'copy_success' => 'Свойства типовой динамической страницы скопировано.',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
);

==> HostCMS-6.8.6.tar: modules/lib/property/i18n/ru.php <==
<?php
/**
 * Libs.
 *
 * @package HostCMS
 * @subpackage Lib
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Свойства типовой динамической страницы',
	'markDeleted_success' => 'Свойство типовой динамической страницы успешно удалено!',
	'lib_property_show_title' => 'Параметры типовой динамической страницы "%s"',
	'lib_property_parametr' => 'Параметр',
	'lib_property_add' => 'Добавить',
	'lib_property_form_title_add' => 'Добавление параметра типовой динамической страницы',
	'name' => 'Название параметра',
	'description' => 'Описание параметра',
	'varible_name' => 'Название переменной',
	'type' => "Тип",
	'default_value' => 'Значение по умолчанию',
	'sorting' => 'Порядок сортировки',
	'lib_property_form_title_edit' => 'Редактирование параметра типовой динамической страницы "%s"',
	'id' => 'Идентификатор',
	'lib_id' => 'Идентификатор типовой динамической страницы',
	'lib_property_type_0' => 'Поле ввода',
	'lib_property_type_1' => 'Флажок',
	'lib_property_type_2' => 'XSL-шаблон',
	'lib_property_type_3' => 'Список',
	'lib_property_type_4' => 'SQL-запрос',
	'lib_property_type_5' => 'Большое текстовое поле',
	'lib_property_type_7' => 'TPL-шаблон',
	'value' => 'Значение',
	'multivalue' => 'Множественные значения',
	'copy_from' => ' [Копия от %s]' ,
	'sql_request' => 'SQL-запрос',
	'sql_caption_field' => 'Поле заголовка',
	'sql_value_field' => 'Поле значения',
	'edit_success' => 'Данные о параметрах динамической странице успешно добавлены/обновлены',
	'edit_error' => 'Ошибка добавления информации о параметре динамической страницы',
	'apply_success' => 'Информация изменена',
	'copy_success' => 'Свойства типовой динамической страницы скопировано.',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
);
